@@ -1,5 +1,5 @@
 
-# Copyright (C) 2013 LiuLang <gsushzhsosgsu@gmail.com>
+# Copyright (C) 2013-2014 LiuLang <gsushzhsosgsu@gmail.com>
 
 # Use of this source code is governed by GPLv3 license that can be found
 # in the LICENSE file.
@@ -14,15 +14,15 @@ from kuwo import Widgets
 _ = Config._
 
 class TopCategories(Gtk.Box):
+    '''Categories tab in notebook.'''
+
+    title = _('Categories')
+
     def __init__(self, app):
         super().__init__(orientation=Gtk.Orientation.VERTICAL)
         self.app = app
-        self.first_show = False
 
     def first(self):
-        if self.first_show:
-            return
-        self.first_show = True
         app = self.app
 
         self.buttonbox = Gtk.Box(spacing=5)
@@ -44,39 +44,39 @@ class TopCategories(Gtk.Box):
         self.buttonbox.pack_start(self.label, False, False, 0)
 
         # checked, name, artist, album, rid, artistid, albumid
-        self.liststore_songs = Gtk.ListStore(bool, str, str, str,
-                int, int, int)
+        self.liststore_songs = Gtk.ListStore(
+                bool, str, str, str, int, int, int)
         self.control_box = Widgets.ControlBox(self.liststore_songs, app)
         self.buttonbox.pack_end(self.control_box, False, False, 0)
 
         self.scrolled_main = Gtk.ScrolledWindow()
         self.pack_start(self.scrolled_main, True, True, 0)
         # logo, name, nid, num of lists(info), tooltip
-        self.liststore_main = Gtk.ListStore(GdkPixbuf.Pixbuf,
-                str, int, str, str)
+        self.liststore_main = Gtk.ListStore(
+                GdkPixbuf.Pixbuf, str, int, str, str)
         iconview_main = Widgets.IconView(self.liststore_main, tooltip=4)
-        iconview_main.connect('item_activated', 
-                self.on_iconview_main_item_activated)
+        iconview_main.connect(
+                'item_activated', self.on_iconview_main_item_activated)
         self.scrolled_main.add(iconview_main)
 
         self.scrolled_sub1 = Gtk.ScrolledWindow()
         self.pack_start(self.scrolled_sub1, True, True, 0)
         # logo, name, nid, num of lists(info), tooltip
-        self.liststore_sub1 = Gtk.ListStore(GdkPixbuf.Pixbuf,
-                str, int, str, str)
+        self.liststore_sub1 = Gtk.ListStore(
+                GdkPixbuf.Pixbuf, str, int, str, str)
         iconview_sub1 = Widgets.IconView(self.liststore_sub1, tooltip=4)
-        iconview_sub1.connect('item_activated', 
-                self.on_iconview_sub1_item_activated)
+        iconview_sub1.connect(
+                'item_activated', self.on_iconview_sub1_item_activated)
         self.scrolled_sub1.add(iconview_sub1)
 
         self.scrolled_sub2 = Gtk.ScrolledWindow()
         self.pack_start(self.scrolled_sub2, True, True, 0)
         # logo, name, nid, info, tooltip
-        self.liststore_sub2 = Gtk.ListStore(GdkPixbuf.Pixbuf,
-                str, int, str, str)
+        self.liststore_sub2 = Gtk.ListStore(
+                GdkPixbuf.Pixbuf, str, int, str, str)
         iconview_sub2 = Widgets.IconView(self.liststore_sub2, tooltip=4)
-        iconview_sub2.connect('item_activated', 
-                self.on_iconview_sub2_item_activated)
+        iconview_sub2.connect(
+                'item_activated', self.on_iconview_sub2_item_activated)
         self.scrolled_sub2.add(iconview_sub2)
 
         self.scrolled_songs = Gtk.ScrolledWindow()
@@ -93,11 +93,10 @@ class TopCategories(Gtk.Box):
         nid = 5
         page = 0
         nodes, total_page = Net.get_nodes(nid, page)
-        if nodes is None:
+        if not nodes:
             print('Failed to get nodes, do something!')
             return
-        i = 0
-        for node in nodes:
+        for i, node in enumerate(nodes):
             self.liststore_main.append([
                 self.app.theme['anonymous'],
                 Widgets.unescape_html(node['disname']),
@@ -105,9 +104,8 @@ class TopCategories(Gtk.Box):
                 Widgets.unescape_html(node['info']),
                 Widgets.set_tooltip(node['disname'], node['info']),
                 ])
-            Net.update_liststore_image(self.liststore_main, i, 0, 
-                    node['pic'])
-            i += 1
+            Net.update_liststore_image(
+                    self.liststore_main, i, 0, node['pic'])
 
     def on_iconview_main_item_activated(self, iconview, path):
         model = iconview.get_model()
@@ -128,7 +126,7 @@ class TopCategories(Gtk.Box):
     def show_sub1(self, init=False):
         def _show_sub1(sub1_args, error=None):
             nodes, self.sub1_total = sub1_args
-            if nodes is None or self.sub1_total == 0:
+            if not nodes or self.sub1_total == 0:
                 return
             i = len(self.liststore_sub1)
             for node in nodes:
@@ -146,9 +144,10 @@ class TopCategories(Gtk.Box):
                     Widgets.unescape_html(node['info']),
                     _tooltip,
                     ])
-                Net.update_liststore_image(self.liststore_sub1, i, 0, 
-                        node['pic'])
+                Net.update_liststore_image(
+                        self.liststore_sub1, i, 0, node['pic'])
                 i += 1
+
             self.sub1_page += 1
             if self.sub1_page < self.sub1_total - 1:
                 self.show_sub1()
@@ -163,8 +162,8 @@ class TopCategories(Gtk.Box):
             self.scrolled_sub1.show_all()
             self.sub1_page = 0
             self.liststore_sub1.clear()
-        Net.async_call(Net.get_nodes, _show_sub1,
-                self.curr_sub1_id, self.sub1_page)
+        Net.async_call(
+                Net.get_nodes, _show_sub1, self.curr_sub1_id, self.sub1_page)
 
     def on_iconview_sub1_item_activated(self, iconview, path):
         model = iconview.get_model()
@@ -185,7 +184,7 @@ class TopCategories(Gtk.Box):
     def show_sub2(self, init=False):
         def _show_sub2(sub2_args, error=None):
             nodes, self.sub2_total = sub2_args
-            if nodes is None or self.sub2_total == 0:
+            if not nodes or self.sub2_total == 0:
                 return
             i = len(self.liststore_sub2)
             for node in nodes:
@@ -194,12 +193,13 @@ class TopCategories(Gtk.Box):
                     Widgets.unescape_html(node['name']),
                     int(node['sourceid']),
                     Widgets.unescape_html(node['info']),
-                    Widgets.set_tooltip_with_song_tips(node['name'],
-                        node['tips']),
+                    Widgets.set_tooltip_with_song_tips(
+                        node['name'], node['tips']),
                     ])
-                Net.update_liststore_image(self.liststore_sub2, i, 0, 
-                        node['pic'])
+                Net.update_liststore_image(
+                        self.liststore_sub2, i, 0, node['pic'])
                 i += 1
+
             self.sub2_page += 1
             if self.sub2_page < self.sub2_total - 1:
                 self.show_sub2()
@@ -211,8 +211,8 @@ class TopCategories(Gtk.Box):
             self.scrolled_sub2.show_all()
             self.sub2_page = 0
             self.liststore_sub2.clear()
-        Net.async_call(Net.get_nodes, _show_sub2,
-                self.curr_sub2_id, self.sub2_page)
+        Net.async_call(
+                Net.get_nodes, _show_sub2, self.curr_sub2_id, self.sub2_page)
 
     def on_iconview_sub2_item_activated(self, iconview, path):
         model = iconview.get_model()
@@ -225,36 +225,39 @@ class TopCategories(Gtk.Box):
     def append_songs(self, init=False):
         def _append_songs(songs_args, error=None):
             songs, self.songs_total = songs_args
-            if len(songs) == 0 or self.songs_total == 0 or self.use_album:
+            if not songs or self.songs_total == 0 or self.use_album:
                 songs = Net.get_album(self.curr_list_id)
                 self.songs_total = 1
-                if songs is None:
+                if not songs:
                     return
                 for song in songs:
-                    self.liststore_songs.append([True,
+                    self.liststore_songs.append([
+                        True,
                         song['name'], 
                         song['artist'],
                         self.curr_list_name, 
                         int(song['id']),
                         int(song['artistid']), 
-                        int(self.curr_list_id), ])
+                        int(self.curr_list_id),
+                        ])
                 return
 
             for song in songs:
-                self.liststore_songs.append([True,
+                self.liststore_songs.append([
+                    True,
                     song['name'],
                     song['artist'],
                     song['album'],
                     int(song['id']),
                     int(song['artistid']), 
-                    int(song['albumid']), ])
+                    int(song['albumid']),
+                    ])
             self.songs_page += 1
             if self.songs_page < self.songs_total - 1:
                 self.append_songs()
 
         if init:
-            self.app.playlist.advise_new_playlist_name(
-                    self.label.get_text())
+            self.app.playlist.advise_new_playlist_name(self.label.get_text())
             self.songs_page = 0
             self.scrolled_sub1.hide()
             self.button_sub1.show_all()
@@ -266,8 +269,9 @@ class TopCategories(Gtk.Box):
             self.scrolled_songs.show_all()
             self.liststore_songs.clear()
 
-        Net.async_call(Net.get_themes_songs, _append_songs,
-                self.curr_list_id, self.songs_page)
+        Net.async_call(
+                Net.get_themes_songs, _append_songs, self.curr_list_id,
+                self.songs_page)
 
     # buttonbox
     def on_button_main_clicked(self, btn):
